@@ -12,6 +12,8 @@ class CreditNotesStream(BaseChargebeeStream):
     VALID_REPLICATION_KEYS = ['updated_at']
     INCLUSION = 'available'
     API_METHOD = 'GET'
+    SCHEMA = 'common/credit_notes'
+    SORT_BY = 'date'
 
     def get_url(self):
         return 'https://{}.chargebee.com/api/v2/credit_notes'.format(self.config.get('site'))
