@@ -12,6 +12,13 @@ class EventsStream(BaseChargebeeStream):
     VALID_REPLICATION_KEYS = ['occurred_at']
     INCLUSION = 'available'
     API_METHOD = 'GET'
+    SCHEMA = 'plan_model/events'
+    SORT_BY = 'occurred_at'
+
+    def __init__(self, config, state, catalog, client):
+        BaseChargebeeStream.__init__(self, config, state, catalog, client)
+        if self.config['item_model']:
+            self.SCHEMA = 'item_model/events'
 
     def get_url(self):
         return 'https://{}.chargebee.com/api/v2/events'.format(self.config.get('site'))
