@@ -12,6 +12,8 @@ class OrdersStream(BaseChargebeeStream):
     VALID_REPLICATION_KEYS = ['updated_at']
     INCLUSION = 'available'
     API_METHOD = 'GET'
+    SCHEMA = 'common/orders'
+    SORT_BY = 'updated_at'
 
     def get_url(self):
         return 'https://{}.chargebee.com/api/v2/orders'.format(self.config.get('site'))
