@@ -12,6 +12,8 @@ class PaymentSourcesStream(BaseChargebeeStream):
     VALID_REPLICATION_KEYS = ['updated_at']
     INCLUSION = 'available'
     API_METHOD = 'GET'
+    SCHEMA = 'common/payment_sources'
+    SORT_BY = None
 
     def get_url(self):
         return 'https://{}.chargebee.com/api/v2/payment_sources'.format(self.config.get('site'))
