@@ -12,6 +12,8 @@ class PromotionalCreditsStream(BaseChargebeeStream):
     VALID_REPLICATION_KEYS = ['created_at']
     INCLUSION = 'available'
     API_METHOD = 'GET'
+    SCHEMA = 'common/promotional_credits'
+    SORT_BY = None
 
     def get_url(self):
         return 'https://{}.chargebee.com/api/v2/promotional_credits'.format(self.config.get('site'))
