@@ -12,6 +12,8 @@ class VirtualBankAccountsStream(BaseChargebeeStream):
     VALID_REPLICATION_KEYS = ['updated_at']
     INCLUSION = 'available'
     API_METHOD = 'GET'
+    SCHEMA = 'common/virtual_bank_accounts'
+    SORT_BY = None
 
     def get_url(self):
         return 'https://{}.chargebee.com/api/v2/virtual_bank_accounts'.format(self.config.get('site'))
